@@ -29,10 +29,5 @@ CODEPRODUIT = {
 
 
 def getnode():
-    from .model.config import AlloConfig
-    config = AlloConfig.load()
-    if hasattr(config, "id_client"):
-        return config.id_client
-    else:
-        random.seed(platform.node() + str(get_mac()))
-        return str(random.randint(1, 999999999999)).zfill(7)
+    random.seed(platform.node() + str(get_mac()))
+    return random.randint(1, 999999999999)
